summaryrefslogtreecommitdiff
path: root/src/smpte_subtitle_asset.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/smpte_subtitle_asset.h')
-rw-r--r--src/smpte_subtitle_asset.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/smpte_subtitle_asset.h b/src/smpte_subtitle_asset.h
index 1521bf35..5d4553a5 100644
--- a/src/smpte_subtitle_asset.h
+++ b/src/smpte_subtitle_asset.h
@@ -211,10 +211,13 @@ private:
boost::optional<Time> _start_time;
std::vector<std::shared_ptr<SMPTELoadFontNode>> _load_font_nodes;
/** UUID for the XML inside the MXF, which should be different to the ID of the MXF according to
* Doremi's 2.8.18 release notes.
*/
std::string _xml_id;
+
+ /** ResourceID read from the MXF, if there was one */
+ boost::optional<std::string> _resource_id;
};
@@ -211,10 +211,13 @@ private:
boost::optional<Time> _start_time;
std::vector<std::shared_ptr<SMPTELoadFontNode>> _load_font_nodes;
- /** UUID for the XML inside the MXF, which should be different to the ID of the MXF according to
- * Doremi's 2.8.18 release notes.
+ /** UUID for the XML inside the MXF, which should be the same as the ResourceID in the MXF (our _resource_id)
+ * but different to the AssetUUID in the MXF (our _id) according to SMPTE Bv2.1 and Doremi's 2.8.18 release notes.
*/
std::string _xml_id;